TrackPos

Struct TrackPos 

pub struct TrackPos {
    pub segment: Entity,
    pub idx: f32,
    pub dir: Option<Dir>,
}
Position of an object along some track segment.

Fields

segment: Entity

The track segment in question.

idx: f32

Position index, treated as a ratio of how far along the segment it is. In range [0.0; 1.0].

dir: Option<Dir>

Encodes which direction the object is facing along the segment. Positive means it is going from 0.0 to 1.0. Some objects can be directionally independent, thus an Option.